==> bigloo_2.4b.orig.tar.gz: bigloo2.4b/comptime/Engine/configure.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Engine/configure.scm        */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Dec 29 09:31:00 2000                          */
;*    Last change :  Fri Nov 30 14:33:57 2001 (serrano)                */
;*    Copyright   :  2000-01 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    The machine dependent configuration.                             */
;*    -------------------------------------------------------------    */
;*    In order to avoid daunting bootstrap problem, I have decided not */
;*    to produce this file automatically. It is written and maintained */
;*    by (my) hand.                                                    */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module engine_configure
   
   (extern (macro bgl-configure-shell::string "SHELL")
	   (macro bgl-configure-c-compiler::string "C_COMPILER")
	   (macro bgl-configure-c-flag::string "C_FLAGS")
	   (macro bgl-configure-c-optim-flag::string "C_OPTIM_FLAGS")
	   (macro bgl-configure-c-strip-flag::string "C_STRIP_FLAGS")
	   (macro bgl-configure-c-prof-flag::string "C_PROFILE_FLAGS")
	   (macro bgl-configure-a.out::string "BGL_DEFAULT_A_OUT")
	   (macro bgl-configure-a.bat::string "BGL_DEFAULT_A_BAT")
	   (macro bgl-configure-library-directory::string "LIBRARY_DIRECTORY")
 	   (macro bgl-configure-zip-directory::string "ZIP_DIRECTORY")
	   (macro bgl-configure-user-libraries::string "USER_LIBRARIES")
	   (macro bgl-configure-c-beautifier::string "C_BEAUTIFIER")
	   (macro bgl-configure-dirname-cmd::string "DIRNAME_CMD")
	   (macro bgl-configure-library-base-name::string "LIBRARY_BASE_NAME")
	   (macro bgl-configure-release-number::string "BGL_RELEASE_NUMBER")
	   (macro bgl-configure-heap-debug-copt::string "BGL_HEAP_DEBUG_COPT")
	   (macro bgl-configure-shared-library-available?::bool "HAVE_SHARED_LIBRARY")
	   (macro bgl-configure-shared-link-option::string "ADDITIONAL_SHARED_LINK_OPTION")
	   (macro bgl-configure-static-link-option::string "ADDITIONAL_STATIC_LINK_OPTION")
	   (macro bgl-configure-dlopen?::bool "HAVE_DLOPEN")
	   (macro bgl-configure-dlopen-lib::string "DLOPEN_LD_OPT")
	   (macro bgl-configure-java::string "BGL_JAVA")
	   (macro bgl-configure-jar::string "BGL_JAR")
	   (macro bgl-configure-java-shell::string "BGL_JAVA_SHELL")
	   (macro bgl-configure-jflags::string "BGL_JAVA_OPT")
	   (macro bgl-configure-jvflags::string "BGL_JAVA_VOPT")
	   (macro bgl-configure-default-back-end::string "BGL_DEFAULT_BACK_END")

	   (macro bgl-foreign-dlopen-init::string "BGL_DYNAMIC_LOAD_INIT")
	   (macro bgl-foreign-BDB_LIBRARY_MAGIC_NUMBER::int "BDB_LIBRARY_MAGIC_NUMBER"))

   
   (java   (class bgl-configure
	      (field static shell::string "SHELL")
	      (field static c-compiler::string "C_COMPILER")
	      (field static c-flag::string "C_FLAGS")
	      (field static c-optim-flag::string "C_OPTIM_FLAGS")
	      (field static c-strip-flag::string "C_STRIP_FLAGS")
	      (field static a.out::string "BGL_DEFAULT_A_OUT")
	      (field static a.bat::string "BGL_DEFAULT_A_BAT")
	      (field static c-prof-flag::string "C_PROFILE_FLAGS")
	      (field static library-directory::string "LIBRARY_DIRECTORY")
	      (field static zip-directory::string "ZIP_DIRECTORY")
	      (field static user-libraries::string "USER_LIBRARIES")
	      (field static c-beautifier::string "C_BEAUTIFIER")
	      (field static dirname-cmd::string "DIRNAME_CMD")
	      (field static library-base-name::string "LIBRARY_BASE_NAME")
	      (field static release-number::string "BGL_RELEASE_NUMBER")
	      (field static heap-debug-copt::string "BGL_HEAP_DEBUG_COPT")
	      (field static shared-library-available?::bool "HAVE_SHARED_LIBRARY")
	      (field static shared-link-option::string "ADDITIONAL_SHARED_LINK_OPTION")
	      (field static static-link-option::string "ADDITIONAL_STATIC_LINK_OPTION")
	      (field static dlopen?::bool "HAVE_DLOPEN")
	      (field static dlopen-lib::string "DLOPEN_LD_OPT")
	      (field static java::string "BGL_JAVA")
	      (field static jar::string "BGL_JAR")
	      (field static java-shell::string "BGL_JAVA_SHELL")
	      (field static jflags::string "BGL_JAVA_OPT")
	      (field static jvflags::string "BGL_JAVA_VOPT")
	      (field static default-back-end::string "BGL_DEFAULT_BACK_END")
	      "bigloo.configure")
	   
	   (class bgl-foreign
	      (field static dlopen-init::string "BGL_DYNAMIC_LOAD_INIT")
	      (field static BDB_LIBRARY_MAGIC_NUMBER::int "BDB_LIBRARY_MAGIC_NUMBER")
	      "bigloo.foreign")))

==> bigloo-4.5b.tar.gz: bigloo-4.5b/comptime/Engine/configure.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime/Engine/configure.scm        */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Dec 29 09:31:00 2000                          */
;*    Last change :  Fri Jun 24 12:11:07 2005 (serrano)                */
;*    Copyright   :  2000-05 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    The machine dependent configuration.                             */
;*    -------------------------------------------------------------    */
;*    In order to avoid daunting bootstrap problem, I have decided not */
;*    to produce this file automatically. It is written and maintained */
;*    by (my) hand.                                                    */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module engine_configure
   
   (extern (macro bgl-foreign-dlopen-init::string "BGL_DYNAMIC_LOAD_INIT")
	   (macro bgl-foreign-BDB_LIBRARY_MAGIC_NUMBER::int "BDB_LIBRARY_MAGIC_NUMBER"))
   
   (java   (class bgl-foreign
	      (field static dlopen-init::string "BGL_DYNAMIC_LOAD_INIT")
	      (field static BDB_LIBRARY_MAGIC_NUMBER::int "BDB_LIBRARY_MAGIC_NUMBER")
	      "bigloo.foreign")))
